# -*- Mode: Python -*-
# vi:si:et:sw=4:sts=4:ts=4
#
# groupvte - settings
# Copyright (C) 2005 Michele Baldessari <michele@pupazzo.org>

# This file may be distributed and/or modified under the terms of
# the GNU General Public License version 2 as published by
# the Free Software Foundation.
# This file is distributed without any warranty; without even the implied
# warranty of merchantability or fitness for a particular purpose.
# See "LICENSE.GPL" in the source distribution for more information.

import unittest
from unittest import TestCase
import settings

class SettingsTestCase(TestCase):
    def setUp(self):
        self.conf = settings.Settings()
        
    def add_machine_test(self):
        machine  = "superpippo"
        commands = ["foo", "bar", "baz"]
        print "Adding machine %s with commands %s" % (machine, commands)
        self.conf.add_machine(machine, commands)
        newcmd = self.conf.get_machine(machine)
        print "Gotten machine %s with commands %s" % (machine, newcmd)
        same = True
        try:
            for i in range(len(commands)):
                if commands[i] != newcmd[i]:
                    same = False
                    break 
        except IndexError:
            same = False
            pass
            
        assert same == True, 'machine commands not stored correctly'
        print "Added machine and gotten machine are the same"

        self.conf.remove_machine(machine)
        print "Removed machine"
        assert self.conf.has_machine(machine) == False, 'machine was not removed succesfully'

        commands = ["foo2", "bar2", "baz2"]
        print "Adding machine %s with commands %s" % (machine, commands)
        self.conf.add_machine(machine, commands)
        newcmd = self.conf.get_machine(machine)
        print "Gotten machine %s with commands %s" % (machine, newcmd)
        same = True
        try:
            for i in range(len(commands)):
                if commands[i] != newcmd[i]:
                    same = False
                    break 
        except IndexError:
            same = False
            pass
            
        assert same == True, 'machine commands not stored correctly'
        print "Added machine and gotten machine are the same"

        self.conf.remove_machine(machine)
        print "Removed machine"
        assert self.conf.has_machine(machine) == False, 'machine was not removed succesfully'
    
    def change_machine_test(self):
        machine  = "superpippo"
        commands = ["foo", "bar", "baz"]
        print "Adding machine %s with commands %s" % (machine, commands)
        self.conf.add_machine(machine, commands)
        commands = ["foo2", "bar", "baz2"]
        self.conf.change_machine(machine, commands)
        print "Changed machine %s to commands %s" % (machine, commands)
        newcmd = self.conf.get_machine(machine)
        print "Gotten machine %s with commands %s" % (machine, newcmd)
        same = True
        try:
            for i in range(len(commands)):
                if commands[i] != newcmd[i]:
                    same = False
                    break 
        except IndexError:
            same = False
            pass
        
        assert same == True, 'machine commands not stored correctly'
        print "Changed machine and gotten machine are the same"

        self.conf.remove_machine(machine)
        print "Removed machine"
        assert self.conf.has_machine(machine) == False, 'machine was not removed succesfully'

    
    def add_session_test(self):
        session  = "superpippo"
        machines = ["foo", "bar", "baz"]
        print ""
        print "Adding session %s with machines %s" % (session, machines)
        self.conf.add_session(session, machines)
        newmachines = self.conf.get_session(session)
        print "Gotten session %s with machines %s" % (session, newmachines)
        same = True
        try:
            for i in range(len(machines)):
                if machines[i] != newmachines[i]:
                    same = False
                    break 
        except IndexError:
            same = False
            pass
            
        assert same == True, 'session machines not stored correctly'
        print "Added session and session machine are the same"

        self.conf.remove_session(session)
        print "Removed session"
        assert self.conf.has_session(session) == False, 'session was not removed succesfully'

    def machine_hash_test(self):
        machine = "superpippo"
        commands = ["foo", "bar", "baz"]
        print "Adding machine %s with commands %s" % (machine, commands)
        self.conf.add_machine(machine, commands)
        machineshash = self.conf.get_machine_hash()
        print "Gotten machines %s" % (machineshash)
        cmds = machineshash[machine]
        same = True
        try:
            for i in range(len(commands)):
                if cmds[i] != commands[i]:
                    same = False
                    break 
        except IndexError:
            same = False
            pass
            
        assert same == True, 'machines not stored correctly'
        print "Added machine and returned machine are the same"
        

        self.conf.remove_machine(machine)
        print "Removed machine"
        assert self.conf.has_machine(machine) == False, 'machine was not removed succesfully'


def suite():
    suite = unittest.TestSuite()
    suite.addTest(SettingsTestCase("add_machine_test"))
    suite.addTest(SettingsTestCase("change_machine_test"))
    suite.addTest(SettingsTestCase("machine_hash_test"))
    suite.addTest(SettingsTestCase("add_session_test"))
    return suite

if __name__ == "__main__":
    unittest.main(defaultTest='suite')
